from setuptools import setup, find_packages

import versioneer

readme_note = """\
.. note::
   For the latest source, discussion, etc, please visit the
   `Bitbucket repository <https://bitbucket.org/creminslab/hiczoom>`_\n\n
"""

with open('README.md') as fobj:
    long_description = readme_note + fobj.read()

setup(
    name='hiczoom',
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    description='Hi-C visualization tool',
    long_description=long_description,
    author='Thomas Gilgenast',
    url='https://bitbucket.org/creminslab/hiczoom',
    packages=find_packages(exclude=["*.tests"]),
    package_data={
        'hiczoom': ['client.html', 'gene_tracks/*', 'chrom_sizes/*',
                    'blank_loops.tsv']
    },
    entry_points={
        'console_scripts': [
            'hiczoom = hiczoom.server:main'
        ]
    },
    install_requires=[
        'numpy>=1.10.4',
        'scipy>=0.16.1',
        'matplotlib>=1.4.3',
        'pandas>=0.18.0',
        'projectile>=0.0.5',
        'Pillow>=4.3.0',
        'tornado>=4.5.2',
        'six>=1.11.0',
        'hiclite>=0.0.1',
    ],
    extras_require={
        'pyBigWig': ['pyBigWig>=0.3.4'],
    },
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Intended Audience :: Science/Research',
        'Programming Language :: Python :: 2.7',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        'Topic :: Multimedia :: Graphics :: Viewers',
        'Topic :: Scientific/Engineering :: Visualization'
    ],
)
